# This program is used to calculate the Scale Factors for Zero-Point Energies, Harmonic Frequencies, and Fundamental Frequencies. 

import random
import sys
import os

NUMER = 0.0   # numerator in eq. 5 of the main paper
DENOM = 0.0   # denominator in eq. 5 of the main paper
LAMBDA = 0.0  # lamda_ZPE on the left side of eq. 5 of the main paper

#read in calculated and experimental frequencies
with open('freqcom.txt') as f:
    f=[x.strip() for x in f if x.strip()]
    data=[tuple(map(float,x.split())) for x in f[0:]]
    zpecom=[x[0] for x in data]
if len(zpecom) == 15:
#calculate scale factor for Zero-Point Energies for the full model
        zpeexp = (16.490, 27.710, 7.3, 3.0929144, 1.302, 16.1, 13.26, 6.231, 10.000, 5.864, 6.770, 3.3618, 21.200, 5.2915, 0.7983)
        for i in range(0,15):
                NUMER = NUMER + zpecom[i]*zpeexp[i]
                DENOM = DENOM + zpecom[i]**2.0
else:
#calculate scale factor for Zero-Point Energies for the reduced model        
        zpeexp = (16.490, 27.710, 16.1, 13.26, 6.770, 21.200)
        for i in range(0,6):
                NUMER = NUMER + zpecom[i]*zpeexp[i]
                DENOM = DENOM + zpecom[i]**2.0
LAMBDA = NUMER/DENOM

#print the results to the screen

print('H. S. Yu, L. J. Fiedler, I. M. Alecu, S. Kanchanakungwankul, and D. G. Truhlar, FREQ - version 2 (University of Minnesota, Minneapolis, 2021).\n')
print('https://comp.chem.umn.edu/freq\n')
print('Scale Factor for Zero-Point Energies     =',LAMBDA,'\n')
print('Scale Factor for Harmonic Frequencies    =',LAMBDA*1.014,'\n')
print('Scale Factor for Fundamental Frequencies =',LAMBDA*0.974,'\n')
print('CITATIONS:\n')
print('1. M. Alecu, J. Zheng, Y. Zhao, and D. G. Truhlar, Computational Thermochemistry: Scale Factor Databases and Scale Factors for Vibrational Frequencies Obtained from Electronic Model Chemistries, Journal of Chemical Theory and Computation 6, 2872-2887 (2010).\n')
print('2. H. S. Yu, L. J. Fiedler, I. M. Alecu, and D. G. Truhlar, Computational Thermochemistry: Automated Generation of Scale Factors for Vibrational Frequencies Calculated by Electronic Structure Model Chemistries Computer Physics Communications 210, 132-138 (2017).\n')
print('3. H. S. Yu, L. J. Fiedler, I. M. Alecu, S. Kanchanakungwankul and D. G. Truhlar, FREQ – version 2 (University of Minnesota, Minneapolis, 2021). https://comp.chem.umn.edu/freq\n')

